# booz_xform

`booz_xform` is a package for computing Boozer coordinates in toroidal magnetohydrodynamic
equilibria, including both stellarators and tokamaks.
For more information, see the [booz_xform documentation here.](https://hiddensymmetries.github.io/booz_xform/)